@@ -1,9 +1,12 @@
-author="CluBear Reserch Group"  
-version="2020-04-23 (0.0.20)" 
+import time
+
+author="CluBear Reserch Group" 
+version=time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()) 
 
 from .dm import manager
 from .pp import pump
 from .ck import check
+from .plt import plot
 
 from .fun import demo
 from .fun import ady
