@@ -25,7 +25,7 @@ def ispump(pp):
 
 def demo():
     
-    mylist=['manager','pump','check']
+    mylist=['manager','pump','check','plot']
     mylist=sorted(mylist)
     
     greeting='''
